==> zio-aws-mgn_2.13-5.17.234.1-sources.jar: zio/aws/mgn/model/PostLaunchActionsDeploymentType.scala <==
package zio.aws.mgn.model
import scala.jdk.CollectionConverters._
sealed trait PostLaunchActionsDeploymentType {
  def unwrap: software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType
}
object PostLaunchActionsDeploymentType {
  def wrap(
      value: software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType
  ): zio.aws.mgn.model.PostLaunchActionsDeploymentType = value match {
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.TEST_AND_CUTOVER =>
      val r = TEST_AND_CUTOVER
      r
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.CUTOVER_ONLY =>
      val r = CUTOVER_ONLY
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.UNKNOWN_TO_SDK_VERSION
  }
  case object TEST_AND_CUTOVER
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.TEST_AND_CUTOVER
  }
  case object CUTOVER_ONLY
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.CUTOVER_ONLY
  }
}

==> zio-aws-mgn_2.13-7.21.15.4-sources.jar: zio/aws/mgn/model/PostLaunchActionsDeploymentType.scala <==
package zio.aws.mgn.model
import scala.jdk.CollectionConverters._
sealed trait PostLaunchActionsDeploymentType {
  def unwrap: software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType
}
object PostLaunchActionsDeploymentType {
  def wrap(
      value: software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType
  ): zio.aws.mgn.model.PostLaunchActionsDeploymentType = value match {
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.TEST_AND_CUTOVER =>
      val r = TEST_AND_CUTOVER
      r
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.CUTOVER_ONLY =>
      val r = CUTOVER_ONLY
      r
    case software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.TEST_ONLY =>
      val r = TEST_ONLY
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.UNKNOWN_TO_SDK_VERSION
  }
  case object TEST_AND_CUTOVER
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.TEST_AND_CUTOVER
  }
  case object CUTOVER_ONLY
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.CUTOVER_ONLY
  }
  case object TEST_ONLY
      extends zio.aws.mgn.model.PostLaunchActionsDeploymentType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType =
      software.amazon.awssdk.services.mgn.model.PostLaunchActionsDeploymentType.TEST_ONLY
  }
}
